﻿namespace ILoan.Tools.Domain.Enums;

/// <summary>
/// The comparison to apply to the rule value.
/// </summary>
[Description("The comparison to apply to the rule value")]
public enum RuleComparison
{
    /// <summary>
    /// The rule should contain a value.
    /// </summary>
    [Display(Name = "contains")]
    Contains,

    /// <summary>
    /// The rule should not contain a value.
    /// </summary>
    [Display(Name = "does not contain")]
    DoesNotContain,

    /// <summary>
    /// The rule should start with a value.
    /// </summary>
    [Display(Name = "starts with")]
    StartsWith,

    /// <summary>
    /// The rule should not start with a value.
    /// </summary>
    [Display(Name = "does not start with")]
    DoesNotStartWith,

    /// <summary>
    /// The rule should be lower than a value.
    /// </summary>
    [Display(Name = "lower than")]
    LowerThan,

    /// <summary>
    /// The rule should be lower than or equal to a value.
    /// </summary>
    [Display(Name = "lower than or equal to")]
    LowerThanOrEqualTo,

    /// <summary>
    /// The rule should be greater than a value.
    /// </summary>
    [Display(Name = "greater than")]
    GreaterThan,

    /// <summary>
    /// The rule should be greater than or equal to a value.
    /// </summary>
    [Display(Name = "greater than or equal to")]
    GreaterThanOrEqualTo,

    /// <summary>
    /// The rule should be equal to a value.
    /// </summary>
    [Display(Name = "is")]
    Is,

    /// <summary>
    /// The rule should not be equal to a value.
    /// </summary>
    [Display(Name = "is not")]
    IsNot,

    /// <summary>
    /// The rule value should be similar to a value.
    /// </summary>
    [Display(Name = "similar to")]
    SimilarTo
}

